<script setup>
import LookupDefault from '@/../component-demos/lookup/examples/LookupDefault.vue';
import LookupWithCustomMenuItem from '@/../component-demos/lookup/examples/LookupWithCustomMenuItem.vue';
import LookupNoResults from '@/../component-demos/lookup/examples/LookupNoResults.vue';
import LookupWithFetch from '@/../component-demos/lookup/examples/LookupWithFetch.vue';
import LookupClearableStartIcon from '@/../component-demos/lookup/examples/LookupClearableStartIcon.vue';
import LookupWithPlaceholder from '@/../component-demos/lookup/examples/LookupWithPlaceholder.vue';
import LookupField from '@/../component-demos/lookup/examples/LookupField.vue';
</script>

A Lookup is a predictive text input that presents a dropdown menu with
suggestions based on the current input value.

## Guidelines

### Using lookups
Use the Lookup component to let users search through a dataset to choose a
predefined value for a form field. This can be useful when there are many
options the user can choose from, so they need to filter the items via a text
query.

Avoid using Lookup to enable users to search for and navigate to content.
Instead, use [SearchInput](./search-input.md) or
[TypeaheadSearch](./typeahead-search.md).

![Example of Codex Lookup.](../../assets/components/lookup-using.svg)

### Specifications
![Specification of Lookup.](../../assets/components/lookup-specifications.svg)

Lookup includes the following elements:
1. **Input**<br>A TextInput where the user types to look for the suggested results. This can optionally include a start icon, clear button, and placeholder text.
2. **Dropdown menu**<br>Suggested results are displayed via the Menu component.

Refer to the [Lookup component in Codex Figma](https://www.figma.com/file/KoDuJMadWBXtsOtzGS4134/%E2%9D%96-Codex-components?type=design&node-id=5034-54226&mode=design&t=2O0ceqiRfqCtnidq-11).

### Types
An input field featuring an optional placeholder will enable users to initiate
their search for suggested results. These suggestions will be displayed within a
dropdown menu, and if the menu cannot fully accommodate the results, a scrollbar
with the choice of infinite scroll can be included.

![Example of Lookup with a custom placeholder.](../../assets/components/lookup-types-scroll.svg)

#### Clearable, with start icon
An optional start icon and clear button could appear within the input field.

![Example of a clearable Lookup component with a custom start icon.](../../assets/components/lookup-types-start-icon.svg)

#### With custom menu item display
Custom content and formats can be applied to change the appearance of menu items
according to your needs.

![Example of Lookup with custom menu items displayed.](../../assets/components/lookup-types-custom-menu.svg)

#### No results
If there are no results for the text typed by the user, a non-interactive "no
results" message will be displayed within the menu.

![Example of a Lookup with no results found.](../../assets/components/lookup-types-no-results.svg)

#### Lookup within a form field

A Lookup can be wrapped within a [Field](./field.md) to include features like
label, description, help text, or validation messages.

![Example of Lookup within a Field component.](../../assets/components/lookup-types-field.svg)

### Interaction states
Interaction can take place within both the input and the displayed menu:

![Interaction states of the Lookup component: default, hover, focus, active, filled, and filled active where a menu item selected is displayed.](../../assets/components/lookup-interaction-states.svg)

1. Default
2. Hover
3. Focus
4. Active
5. Filled
6. Filled active (with a menu item selected)

## Demos

### Default

The Lookup component will emit `input` events on input, which the parent component should
react to by computing or fetching menu items, then providing those items to the Lookup component for
display by updating the `menu-items` prop.

Items are displayed via the MenuItem component—see the [MenuItem docs](./menu-item) for more
options. In this example, a `menuConfig` object is passed to the Lookup to bold the label text.

Note that in this example, menu items are Wikidata items with a human-readable label and a Wikidata
entity ID value.

::: warning
The parent component must update the `menu-items` prop after each `input` event, otherwise
the Lookup component will stay in the pending state indefinitely. If there are no results for the
given input, set the `menu-items` prop to an empty array (`[]`).
:::

<cdx-demo-wrapper :force-controls="true">
<template v-slot:demo>
	<lookup-default />
</template>
<template v-slot:code>

:::code-group

<<< @/../component-demos/lookup/examples/LookupDefault.vue [NPM]

<<< @/../component-demos/lookup/examples-mw/LookupDefault.vue [MediaWiki]

:::

</template>
</cdx-demo-wrapper>

### With custom menu item display

The `menu-item` slot can be used to set up custom menu item content and formatting.

<cdx-demo-wrapper>
<template v-slot:demo>
	<lookup-with-custom-menu-item />
</template>
<template v-slot:code>

:::code-group

<<< @/../component-demos/lookup/examples/LookupWithCustomMenuItem.vue [NPM]

<<< @/../component-demos/lookup/examples-mw/LookupWithCustomMenuItem.vue [MediaWiki]

:::

</template>
</cdx-demo-wrapper>

### With "no results" content

A non-interactive "no results" message can be displayed via the `no-results` slot. If populated,
this slot will automatically display when there are zero menu items.

<cdx-demo-wrapper>
<template v-slot:demo>
	<lookup-no-results />
</template>
<template v-slot:code>

:::code-group

<<< @/../component-demos/lookup/examples/LookupNoResults.vue [NPM]

<<< @/../component-demos/lookup/examples-mw/LookupNoResults.vue [MediaWiki]

:::

</template>
</cdx-demo-wrapper>

### With fetched results and infinite scroll

Often, Lookup is used to fetch results from an API endpoint. Parent components should
react to the `input` event emitted by Lookup to search for results, then pass back to the
Lookup either an array of results to display as menu items or an empty array if there are no
results. Between those two events, a pending state animation will display in the input.

Scrolling is enabled by setting the `visibleItemLimit` property of the `menuConfig` prop.

With scrolling enabled, when the user nears the end of the list of results, a `load-more` event is
emitted. The parent component can react to this by fetching more results and appending them to the
list of menu items provided to the Lookup. These new items will then be displayed within the menu.

<cdx-demo-wrapper>
<template v-slot:demo>
	<lookup-with-fetch />
</template>
<template v-slot:code>

:::code-group

<<< @/../component-demos/lookup/examples/LookupWithFetch.vue [NPM]

<<< @/../component-demos/lookup/examples-mw/LookupWithFetch.vue [MediaWiki]

:::

</template>
</cdx-demo-wrapper>

### Clearable, with start icon

Props of the TextInput component can be bound to Lookup and will be passed down to the TextInput
component inside of it, so you can take advantage of features like the "clear" button and icons.

<cdx-demo-wrapper>
<template v-slot:demo>
	<lookup-clearable-start-icon />
</template>
<template v-slot:code>

:::code-group

<<< @/../component-demos/lookup/examples/LookupClearableStartIcon.vue [NPM]

<<< @/../component-demos/lookup/examples-mw/LookupClearableStartIcon.vue [MediaWiki]

:::

</template>
</cdx-demo-wrapper>

### With placeholder

Attributes (except for `class`) will fall through to the input element, so you can set things like
`placeholder` on the Lookup component and they'll be applied to the input.

<cdx-demo-wrapper>
<template v-slot:demo>
	<lookup-with-placeholder />
</template>
<template v-slot:code>

:::code-group

<<< @/../component-demos/lookup/examples/LookupWithPlaceholder.vue [NPM]

<<< @/../component-demos/lookup/examples-mw/LookupWithPlaceholder.vue [MediaWiki]

:::

</template>
</cdx-demo-wrapper>

### Form field

A Lookup can be wrapped in the Field component to add features like a semantic label, description
and help text, validation messages, and more. See the [Field](./field.md) page for more information.

<cdx-demo-wrapper>
<template v-slot:demo>
	<lookup-field />
</template>
<template v-slot:code>

:::code-group

<<< @/../component-demos/lookup/examples/LookupField.vue [NPM]

<<< @/../component-demos/lookup/examples-mw/LookupField.vue [MediaWiki]

:::

</template>
</cdx-demo-wrapper>

## Vue usage

Typical use of this component will involve listening for `input` events, fetching or otherwise
computing menu items, then passing those menu items back to the Lookup for display.

::: tip TextInput props apply
This component contains a TextInput component. You can bind [TextInput props](./text-input.html#usage)
to this component and they will be passed to the TextInput within.
:::

::: tip Attributes passed to input
This component will pass any HTML attributes applied to it, except for CSS class, to the `<input>`
element within the component.
:::

## CSS-only version

### Markup structure

There is no true CSS-only version of the Lookup component. However, a
[CSS-only TextInput component](./text-input.md#css-only-version) can be used instead, since it has
visual parity with the Lookup component with its menu collapsed. For example, you could display a
CSS-only TextInput on page load while a Vue app loads, then replace it with the Vue Lookup component once the Vue app has mounted.

The example below is a simple text input with a placeholder, but icons and different states are
supported—see the [TextInput docs](./text-input.md#css-only-version) for more information.


<cdx-demo-wrapper>
<template v-slot:demo>
	<div class="cdx-text-input">
		<input class="cdx-text-input__input" type="text" placeholder="Start typing a vegetable name...">
	</div>
</template>
<template v-slot:code>

```html
<!-- Wrapper div. -->
<div class="cdx-text-input">
	<!-- Input element with CSS class and attributes. -->
	<input class="cdx-text-input__input" type="text" placeholder="Start typing a vegetable name...">
</div>
```

</template>
</cdx-demo-wrapper>
